@@ -7,22 +7,26 @@ use ross_config::producer::*;
 
 use crate::error::{ErrorKind, ParserError};
 use crate::literal::Literal;
-use crate::parser::{argument0, name_parser};
+use crate::parser::{argument_or_constant0, name_parser};
 use crate::symbol::semicolon;
-use crate::{impl_item_arg0, impl_item_arg1, impl_item_arg3};
+use crate::{impl_item_arg0, impl_item_arg1, impl_item_arg3, impl_item_arg4};
 
 pub fn producer<'a>(
     constants: &'a BTreeMap<&str, Literal>,
 ) -> impl FnMut(&str) -> IResult<&str, Box<dyn Producer>, ParserError<&str>> + 'a {
     move |text| {
-        let (input, (name, arguments)) =
-            terminated(pair(name_parser, argument0(constants)), semicolon)(text)?;
+        let (input, (name, arguments)) = terminated(
+            pair(name_parser, argument_or_constant0(constants)),
+            semicolon,
+        )(text)?;
 
         impl_item_arg0!(input, name, arguments, NoneProducer);
         impl_item_arg1!(input, name, arguments, PacketProducer);
         impl_item_arg3!(input, name, arguments, MessageProducer);
         impl_item_arg3!(input, name, arguments, BcmChangeBrightnessProducer);
         impl_item_arg3!(input, name, arguments, BcmChangeBrightnessStateProducer);
+        impl_item_arg4!(input, name, arguments, BcmAnimateBrightnessProducer);
+        impl_item_arg4!(input, name, arguments, BcmAnimateBrightnessStateProducer);
 
         Err(Err::Error(ParserError::Base {
             location: name,
@@ -36,9 +40,13 @@ pub fn producer<'a>(
 mod tests {
     use super::*;
 
+    use ross_protocol::event::bcm::BcmValue;
     use ross_protocol::event::message::MessageValue;
 
-    use crate::{impl_tests_for_item_arg0, impl_tests_for_item_arg1, impl_tests_for_item_arg3};
+    use crate::{
+        impl_tests_for_item_arg0, impl_tests_for_item_arg1, impl_tests_for_item_arg3,
+        impl_tests_for_item_arg4,
+    };
 
     impl_tests_for_item_arg0!(none_producer, producer, NoneProducer);
     impl_tests_for_item_arg1!(
@@ -61,7 +69,7 @@ mod tests {
         BcmChangeBrightnessProducer,
         ("0xabab~u16", 0xabab),
         ("0x01~u8", 0x01),
-        ("0xff~u8", 0xff)
+        ("#234567", BcmValue::Rgb(0x23, 0x45, 0x67))
     );
     impl_tests_for_item_arg3!(
         bcm_change_brightness_state_producer,
@@ -71,4 +79,22 @@ mod tests {
         ("0x01~u8", 0x01),
         ("0xabababab~u32", 0xabab_abab)
     );
+    impl_tests_for_item_arg4!(
+        bcm_animate_brightness_producer,
+        producer,
+        BcmAnimateBrightnessProducer,
+        ("0xabab~u16", 0xabab),
+        ("0x01~u8", 0x01),
+        ("0xabababab~u32", 0xabab_abab),
+        ("#234567", BcmValue::Rgb(0x23, 0x45, 0x67))
+    );
+    impl_tests_for_item_arg4!(
+        bcm_animate_brightness_producer,
+        producer,
+        BcmAnimateBrightnessStateProducer,
+        ("0xabab~u16", 0xabab),
+        ("0x01~u8", 0x01),
+        ("0xabababab~u32", 0xabab_abab),
+        ("0xffffffff~u32", 0xffff_ffff)
+    );
 }
